@@ -28,7 +28,6 @@ from nbxmpp.errors import is_error
 from nbxmpp.errors import MalformedStanzaError
 from nbxmpp.errors import StanzaError
 from nbxmpp.errors import TimeoutStanzaError
-from nbxmpp.http import HTTPRequest
 from nbxmpp.modules.util import make_func_arguments_string
 from nbxmpp.simplexml import Node
 
@@ -109,21 +108,6 @@ def iq_request_task(func: Callable[..., T]) -> Callable[..., T]:
     return func_wrapper
 
 
-def http_request_task(func: Callable[P, T]) -> Callable[P, T]:
-    @wraps(func)
-    def func_wrapper(
-        self: NBXMPPModuleT,
-        *args: Any,
-        callback: Callable[..., Any] | None = None,
-        user_data: Any = None,
-        **kwargs: Any,
-    ) -> T:
-        task = HTTPRequestTask(func(self, *args, **kwargs), self._log)  # type: ignore
-        return _setup_task(task, self._client, callback, user_data)  # type: ignore
-
-    return func_wrapper
-
-
 def is_fatal_error(error: BaseError | Exception | Any) -> bool:
     if is_error(error):
         assert isinstance(error, BaseError)
@@ -386,28 +370,3 @@ class IqRequestTask(Task):
             self._client._dispatcher.remove_iq_callback(self._iq_id)  # type: ignore
         self._client = None
         super()._finalize()
-
-
-class HTTPRequestTask(Task):
-    """
-    A Task for running HTTP requests
-
-    """
-
-    _process_types = (HTTPRequest,)
-
-    def __init__(self, gen: Generator[Any, Any, Any], logger: logging.Logger) -> None:
-        super().__init__(gen, logger)
-
-    def _run_async(self, data: HTTPRequest) -> None:
-        data.connect("finished", self._async_finished)
-
-    def _async_finished(self, request: HTTPRequest) -> None:
-        if self._state == TaskState.CANCELLED:
-            return
-
-        self._next_step(request)
-
-    def _finalize(self) -> None:
-        self._session = None
-        super()._finalize()
